@@ -114,52 +114,40 @@ func mapBrowserContext(vu moduleVU, bc *common.BrowserContext) mapping { //nolin
 			})
 		},
 		"waitForEvent": func(event string, optsOrPredicate sobek.Value) (*sobek.Promise, error) {
-			popts, err := parseWaitForEventOptions(vu.Runtime(), optsOrPredicate, bc.Timeout())
+			rt := vu.Runtime()
+			ctx := vu.Context()
+
+			popts, err := parseWaitForEventOptions(rt, optsOrPredicate, bc.Timeout())
 			if err != nil {
 				return nil, fmt.Errorf("parsing wait for event options: %w", err)
 			}
 
-			ctx := vu.Context()
-			return promise(vu, func() (result any, reason error) {
-				var runInTaskQueue func(p *common.Page) (bool, error)
-				if popts.PredicateFn != nil {
-					runInTaskQueue = func(p *common.Page) (bool, error) {
-						tq := vu.get(ctx, p.TargetID())
+			// Waits until the first event if no predicate is specified.
+			var pred func(p *common.Page) (bool, error)
 
-						var rtn bool
-						var err error
-						// The function on the taskqueue runs in its own goroutine
-						// so we need to use a channel to wait for it to complete
-						// before returning the result to the caller.
-						c := make(chan bool)
-						tq.Queue(func() error {
-							var resp sobek.Value
-							resp, err = popts.PredicateFn(vu.Runtime().ToValue(p))
-							rtn = resp.ToBoolean()
-							close(c)
-							return nil
-						})
-
-						select {
-						case <-c:
-						case <-ctx.Done():
-							err = errors.New("iteration ended before waitForEvent completed")
+			// Waits until the event that satisfies the predicate.
+			if popts.PredicateFn != nil {
+				pred = func(p *common.Page) (bool, error) {
+					return queueTask(ctx, vu.get(ctx, p.TargetID()), func() (bool, error) {
+						v, err := popts.PredicateFn(rt.ToValue(p))
+						if err != nil {
+							return false, err
 						}
-
-						return rtn, err //nolint:wrapcheck
-					}
+						return v.ToBoolean(), nil
+					})()
 				}
+			}
 
-				resp, err := bc.WaitForEvent(event, runInTaskQueue, popts.Timeout)
-				panicIfFatalError(ctx, err)
+			return promise(vu, func() (result any, reason error) {
+				v, err := bc.WaitForEvent(event, pred, popts.Timeout)
 				if err != nil {
-					return nil, err //nolint:wrapcheck
+					panicIfFatalError(ctx, err)
+					return nil, err
 				}
-				p, ok := resp.(*common.Page)
+				p, ok := v.(*common.Page)
 				if !ok {
 					panicIfFatalError(ctx, fmt.Errorf("response object is not a page: %w", k6error.ErrFatal))
 				}
-
 				return mapPage(vu, p), nil
 			}), nil
 		},
