@@ -49,6 +49,8 @@ type eventInterceptor interface {
 	urlTagName(urlTag string, method string) (string, bool)
 	onRequest(request *Request)
 	onResponse(response *Response)
+	onRequestFinished(request *Request)
+	onRequestFailed(request *Request)
 }
 
 // NetworkManager manages all frames in HTML document.
@@ -422,6 +424,7 @@ func (m *NetworkManager) onLoadingFailed(event *network.EventLoadingFailed) {
 
 	req.setErrorText(event.ErrorText)
 	req.responseEndTiming = float64(event.Timestamp.Time().Unix()-req.timestamp.Unix()) * 1000
+	m.eventInterceptor.onRequestFailed(req)
 	m.deleteRequestByID(event.RequestID)
 	m.frameManager.requestFailed(req, event.Canceled)
 }
@@ -436,6 +439,7 @@ func (m *NetworkManager) onLoadingFinished(event *network.EventLoadingFinished)
 	req.responseEndTiming = float64(event.Timestamp.Time().Unix()-req.timestamp.Unix()) * 1000
 	m.deleteRequestByID(event.RequestID)
 	m.frameManager.requestFinished(req)
+	m.eventInterceptor.onRequestFinished(req)
 
 	// Skip data and blob URLs when emitting metrics, since they're internal to the browser.
 	if isInternalURL(req.url) {
